==> Botania-1.20.1-449-FABRIC-20250524.060819-20-sources.jar: vazkii/botania/test/item/lens/EntropicWarpLensTest.java <==
package vazkii.botania.test.item.lens;

import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2453;
import net.minecraft.class_4516;
import net.minecraft.class_6302;
import vazkii.botania.common.block.ForceRelayBlock;
import vazkii.botania.common.block.ForceRelayBlock.WorldData;
import vazkii.botania.common.block.block_entity.BotaniaBlockEntities;
import vazkii.botania.common.block.block_entity.mana.ManaSpreaderBlockEntity;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.test.TestingUtil;

public class EntropicWarpLensTest {

	@class_6302(method_35936 = "botania:item/lens/entropic_warp_lens")
	public void testWarp(class_4516 helper) {
		var spreaderPos = new class_2338(3, 3, 3);
		var lampPos = new class_2338(2, 4, 3);
		var buttonPos = new class_2338(4, 3, 3);
		var relayPos = new class_2338(3, 2, 3);
		var bindPos = new class_2338(3, 10, 3);
		var player = helper.method_36021();

		var data = ForceRelayBlock.WorldData.get(helper.method_35943());
		data.mapping.put(helper.method_36052(relayPos), helper.method_36052(bindPos));

		var spreader = TestingUtil.assertBlockEntity(helper, spreaderPos, BotaniaBlockEntities.SPREADER);

		TestingUtil.assertThat(spreader.bindTo(player, new class_1799(BotaniaItems.twigWand), helper.method_36052(relayPos), class_2350.field_11033),
				() -> "Failed to bind spreader");

		helper.method_36041()
				.method_36085(() -> helper.method_36026(buttonPos))
				.method_36079(() -> helper.method_35987(lampPos, class_2453.field_11413, true))
				.method_36075();

	}

}

==> Botania-1.20.1-451-FABRIC-20260101.094133-38-sources.jar: vazkii/botania/test/item/lens/EntropicWarpLensTest.java <==
package vazkii.botania.test.item.lens;

import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2453;
import net.minecraft.class_4516;
import net.minecraft.class_6302;
import vazkii.botania.common.block.ForceRelayBlock;
import vazkii.botania.common.block.ForceRelayBlock.WorldData;
import vazkii.botania.common.block.block_entity.BotaniaBlockEntities;
import vazkii.botania.common.block.block_entity.mana.ManaSpreaderBlockEntity;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.test.TestingUtil;

public class EntropicWarpLensTest {

	@class_6302(method_35936 = "botania:item/lens/entropic_warp_lens")
	public void testWarp(class_4516 helper) {
		var spreaderPos = new class_2338(3, 3, 3);
		var lampPos = new class_2338(2, 4, 3);
		var buttonPos = new class_2338(4, 3, 3);
		var relayPos = new class_2338(3, 2, 3);
		var bindPos = new class_2338(3, 10, 3);
		var player = helper.method_36021();

		var data = ForceRelayBlock.WorldData.get(helper.method_35943());
		data.mapping.put(helper.method_36052(relayPos), helper.method_36052(bindPos));

		var spreader = TestingUtil.assertBlockEntity(helper, spreaderPos, BotaniaBlockEntities.SPREADER);

		TestingUtil.assertThat(spreader.bindTo(player, new class_1799(BotaniaItems.twigWand), helper.method_36052(relayPos), class_2350.field_11033),
				() -> "Failed to bind spreader");

		helper.method_36041()
				.method_36077(1, () -> helper.method_36026(buttonPos))
				.method_36079(() -> helper.method_35987(lampPos, class_2453.field_11413, true))
				.method_36075();

	}

}
